Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(800)

Unified Diff: components/update_client/update_query_params_delegate.h

Issue 803313003: Rename omaha_client and similar tokens to update_client in all contexts. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@lkgr
Patch Set: rebase to master Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/update_client/update_query_params_delegate.h
diff --git a/components/omaha_client/omaha_query_params_delegate.h b/components/update_client/update_query_params_delegate.h
similarity index 51%
rename from components/omaha_client/omaha_query_params_delegate.h
rename to components/update_client/update_query_params_delegate.h
index ab52436beaf7ea55d075961c8fa90a64dda42cac..0dd97ff530b3ce682876cd3210f79f416dce2d0d 100644
--- a/components/omaha_client/omaha_query_params_delegate.h
+++ b/components/update_client/update_query_params_delegate.h
@@ -2,31 +2,31 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef COMPONENTS_OMAHA_CLIENT_OMAHA_QUERY_PARAMS_DELEGATE_H_
-#define COMPONENTS_OMAHA_CLIENT_OMAHA_QUERY_PARAMS_DELEGATE_H_
+#ifndef COMPONENTS_UPDATE_CLIENT_UPDATE_QUERY_PARAMS_DELEGATE_H_
+#define COMPONENTS_UPDATE_CLIENT_UPDATE_QUERY_PARAMS_DELEGATE_H_
#include <string>
#include "base/basictypes.h"
-namespace omaha_client {
+namespace update_client {
-// Embedders can specify an OmahaQueryParamsDelegate to provide additional
+// Embedders can specify an UpdateQueryParamsDelegate to provide additional
// custom parameters. If not specified (Set is never called), no additional
// parameters are added.
-class OmahaQueryParamsDelegate {
+class UpdateQueryParamsDelegate {
public:
- OmahaQueryParamsDelegate();
- virtual ~OmahaQueryParamsDelegate();
+ UpdateQueryParamsDelegate();
+ virtual ~UpdateQueryParamsDelegate();
// Returns additional parameters, if any. If there are any parameters, the
// string should begin with a & character.
virtual std::string GetExtraParams() = 0;
private:
- DISALLOW_COPY_AND_ASSIGN(OmahaQueryParamsDelegate);
+ DISALLOW_COPY_AND_ASSIGN(UpdateQueryParamsDelegate);
};
-} // namespace omaha_client
+} // namespace update_client
-#endif // COMPONENTS_OMAHA_CLIENT_OMAHA_QUERY_PARAMS_DELEGATE_H_
+#endif // COMPONENTS_UPDATE_CLIENT_UPDATE_QUERY_PARAMS_DELEGATE_H_
« no previous file with comments | « components/update_client/update_query_params.cc ('k') | components/update_client/update_query_params_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698